Boost logo

Boost-Commit :

From: hervebronnimann_at_[hidden]
Date: 2007-06-14 00:35:46


Author: hervebronnimann
Date: 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
New Revision: 7039
URL: http://svn.boost.org/trac/boost/changeset/7039

Log:
Minor update. Remove dev/doxy (no longer needed, can apply doxygen filter directly).

Removed:
   sandbox/SOC/2007/geometry/libs/hdstl/dev/doxy/
   sandbox/SOC/2007/geometry/libs/hdstl/tools/make_doc.sh
Text files modified:
   sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/forward_hds_concept_archetype.hpp | 194 ++++++++++++++++++++++++++++-----------
   sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/hds_concept_archetype.hpp | 105 ++++++++++++++-------
   sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_concepts/mutable_vertex_hds_concept.hpp | 2
   sandbox/SOC/2007/geometry/libs/hdstl/doc/hdstl.conf | 6
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp-source.html | 39 +++----
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp.html | 3
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backwardhds.html | 3
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/files.html | 18 +++
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp-source.html | 39 +++----
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp.html | 3
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forwardhds.html | 5
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp-source.html | 49 ++++-----
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp.html | 4
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hdsconcept.html | 3
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/index.html | 3
   sandbox/SOC/2007/geometry/libs/hdstl/doc/html/pages.html | 27 +++++
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/doxygen.sty | 4
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/files.tex | 15 +++
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/forwardhds.tex | 2
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/hds__concept_8hpp.tex | 1
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/pages.tex | 24 ++++
   sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/refman.tex | 34 ++++++
   sandbox/SOC/2007/geometry/libs/hdstl/tools/doc.pl | 77 +++++++++------
   23 files changed, 448 insertions(+), 212 deletions(-)

Modified: sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/forward_hds_concept_archetype.hpp
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/forward_hds_concept_archetype.hpp (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/forward_hds_concept_archetype.hpp 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -1,61 +1,141 @@
-/**
- * @file forward_hds_concept_archetype.hpp
- *
- * @brief ForwardHDS concept archetype
- *
- * @par Definition
- * This file provides an archetype class for compile time testing of the
- * ForwardHDSConcept class.
- *
- * @par Archetype class
- * \code
- * class ForwardHDSConcept_archetype
- * :HDSConcept_archetype {
- * public:
- * halfedge_descriptor& next_in_faccet(ForwardHDSConcept_archetype,
- * halfedge_descriptor&) const{};
- * halfedge_descriptor& next_at_source(ForwardHDSConcept_archetype,
- * halfedge_descriptor&) const{};
- * halfedge_descriptor& next_at_target(ForwardHDSConcept_archetype,
- * halfedge_descriptor&) const{};
- *
- * };
- * template<>
- * class hds_traits<ForwardHDSConcept_archetype> {
- * struct halfedge_descriptor
- * :public boost::default_constructible_archetype,
- * boost::copy_constructible_archetype,
- * boost::equality_comparable_archetype,
- * boost::assignable_archetype {};
- *
- * struct traversal_category
- * :public boost::convertible_to_archetype<forward_traversal_tag>
- * {};
- * };
- * \endcode
- */
-#include <boost/concept_archetype.hpp>
+// forward_hds_concept_archetype.hpp -*- C++ -*-
+//
+//@PURPOSE: Provide a 'ForwardHDS' concept archetype
+//
+//@DESCRIPTION: This file provides an archetype class for compile-time testing
+// of the 'ForwardHDSConcept' class. Namely, this class can be used wherever a
+// template parameter of a class or of a function template is required to be a
+// model of the 'ForwardHDS' concept, in order to ensure that no further
+// requirements are placed on the template parameter than are stated in the
+// 'ForwardHDS' concept.
+//
+///Archetype class
+///---------------
+//..
+// class ForwardHDSConcept_archetype
+// :HDSConcept_archetype {
+// public:
+// halfedge_descriptor& next_in_faccet(ForwardHDSConcept_archetype,
+// halfedge_descriptor&) const{};
+// halfedge_descriptor& next_at_source(ForwardHDSConcept_archetype,
+// halfedge_descriptor&) const{};
+// halfedge_descriptor& next_at_target(ForwardHDSConcept_archetype,
+// halfedge_descriptor&) const{};
+//
+// };
+// template<>
+// class hds_traits<ForwardHDSConcept_archetype> {
+// struct halfedge_descriptor
+// :public boost::default_constructible_archetype,
+// boost::copy_constructible_archetype,
+// boost::equality_comparable_archetype,
+// boost::assignable_archetype {};
+//
+// struct traversal_category
+// :public boost::convertible_to_archetype<forward_traversal_tag>
+// {};
+// };
+//..
 
-class ForwardHDSConcept_archetype
- :HDSConcept_archetype {
- public:
- halfedge_descriptor& next_in_faccet(ForwardHDSConcept_archetype,
- halfedge_descriptor&) const{};
- halfedge_descriptor& next_at_source(ForwardHDSConcept_archetype,
- halfedge_descriptor&) const{};
- halfedge_descriptor& next_at_target(ForwardHDSConcept_archetype,
- halfedge_descriptor&) const{};
+#ifndef BOOST_HDSTL_FORWARD_HDS_CONCEPT_ARCHETYPE_HPP
+#define BOOST_HDSTL_FORWARD_HDS_CONCEPT_ARCHETYPE_HPP
+
+#include <boost/hds_archetype/hds_concept_archetypes.hpp>
+
+namespace boost {
+namespace hdstl {
+
+template <typename ForwardCategory>
+class ForwardHDSConcept_archetype; // forward declaration
+
+template <typename ForwardCategory>
+struct hds_traits<ForwardHDSConcept_archetype<ForwardCategory> > {
+ // This template specialization of 'hds_traits' for the
+ // 'ForwardHDSConcept_archetype' provides the 'halfedge_descriptor' and
+ // 'traversal_category' types.
+
+ // TYPES
+ typedef boost::default_constructible_archetype<
+ boost::copy_constructible_archetype<
+ boost::equality_comparable_archetype<
+ boost::assignable_archetype<> > > > halfedge_descriptor;
+ // Halfedge descriptor type for the 'ForwardHDSConcept' archetype.
 
+ typedef boost::convertible_to_archetype<forward_traversal_tag>
+ traversal_category;
+ // This type, convertible to 'forward_traversal_tag', indicates that
+ // the 'ForwardHDSConcept' archetype is a model of 'ForwardHDSConcept'.
+
+ typedef ForwardCategory forward_category;
+ // This type, convertible to one or more of 'next_in_facet_tag',
+ // 'next_at_source_tag', or 'next_at_target_tag', indicates which is
+ // the primary accessor(s) for which the 'set_...' methods are defined.
 };
-template<>
-class hds_traits<ForwardHDSConcept_archetype> {
- struct halfedge_descriptor
- :public boost::default_constructible_archetype,
- boost::copy_constructible_archetype,
- boost::equality_comparable_archetype,
- boost::assignable_archetype {};
-
- struct traversal_category
- :public boost::convertible_to_archetype<forward_traversal_tag>
- {};
+
+
+template <typename ForwardCategory>
+class ForwardHDSConcept_archetype : public HDSConcept_archetype {
+ // This class provides an exact implementation (no more, no less) of the
+ // 'ForwardHDS' concept. It can be used to instantiate class and function
+ // templates that require their template arguments to be a model of this
+ // concept in order to verify that there are no extra syntactic
+ // requirements.
+
+ // PRIVATE TYPES
+ typedef typename hds_traits<ForwardHDSConcept_archetype
+ >::halfedge_descriptor halfedge_descriptor;
+
+ // NOT IMPLEMENTED
+ ForwardHDSConcept_archetype();
+ ForwardHDSConcept_archetype(const ForwardHDSConcept_archetype&);
+
+ public:
+ // MANIPULATORS
+ halfedge_descriptor
+ next_in_facet(ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h) const;
+ // Return the halfedge following 'h' in the (counter-clockwise) facet
+ // cycle of 'h' in 'hds'.
+
+ halfedge_descriptor
+ next_at_source(ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h) const;
+ // Returns the halfedge following 'h' in the (clockwise) vertex
+ // cycle of the source of 'h' in 'hds'.
+
+ halfedge_descriptor
+ next_at_target(ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h) const;
+ // Returns the halfedge following 'h' in the (clockwise) vertex
+ // cycle of the target of 'h' in 'hds'.
 };
+
+// MANIPULATORS
+template <typename ForwardCategory>
+typename hds_traits<ForwardHDSConcept_archetype>::halfedge_descriptor
+ForwardHDSConcept_archetype<ForwardCategory>::next_in_facet(
+ ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h)
+{
+ return halfedge_descriptor();
+}
+
+template <typename ForwardCategory>
+typename hds_traits<ForwardHDSConcept_archetype>::halfedge_descriptor
+ForwardHDSConcept_archetype<ForwardCategory>::next_at_source(
+ ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h)
+{
+ return halfedge_descriptor();
+}
+
+template <typename ForwardCategory>
+typename hds_traits<ForwardHDSConcept_archetype>::halfedge_descriptor
+ForwardHDSConcept_archetype<ForwardCategory>::next_at_target(
+ ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h)
+{
+ return halfedge_descriptor();
+}
+
+#endif

Modified: sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/hds_concept_archetype.hpp
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_concepts/mutable_vertex_hds_concept.hpp (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_concepts/mutable_vertex_hds_concept.hpp 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -14,7 +14,7 @@
 // inside a class body, checks whether the type given as template
 // argument is a model of the HDS concept described on the page [mutablevertexhds].
 //
-//@CONCEPT: [mutablevertexhds] Vertex HDS concept
+//@CONCEPT: [mutablevertexhds] Mutable Vertex HDS concept
 //
 ///Definition
 ///----------

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/hdstl.conf
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/hdstl.conf (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/hdstl.conf 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -459,7 +459,7 @@
 # directories like "/usr/src/myproject". Separate the files or directories
 # with spaces.
 
-INPUT = "../dev/doxy"
+INPUT = "../dev"
 
 # If the value of the INPUT tag contains directories, you can use the
 # FILE_PATTERNS tag to specify one or more wildcard pattern (like *.cpp
@@ -530,7 +530,7 @@
 # to standard output. If FILTER_PATTERNS is specified, this tag will be
 # ignored.
 
-INPUT_FILTER =
+INPUT_FILTER = "../tools/doc.pl"
 
 # The FILTER_PATTERNS tag can be used to specify filters on a per file pattern
 # basis. Doxygen will compare the file name with each pattern and apply the
@@ -545,7 +545,7 @@
 # INPUT_FILTER) will be used to filter the input files when producing source
 # files to browse (i.e. when SOURCE_BROWSER is set to YES).
 
-FILTER_SOURCE_FILES = NO
+FILTER_SOURCE_FILES = YES
 
 #---------------------------------------------------------------------------
 # configuration options related to source browsing

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp-source.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp-source.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp-source.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,24 +8,24 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>backward_hds_concept.hpp</h1>Go to the documentation of this file.<div class="fragment"><pre class="fragment"><a name="l00001"></a>00001
-<a name="l00119"></a>00119 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_BACKWARDHDSCONCEPT_HPP</span>
-<a name="l00120"></a>00120 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_BACKWARDHDSCONCEPT_HPP 1</span>
-<a name="l00121"></a>00121 <span class="preprocessor"></span>
-<a name="l00122"></a>00122 <span class="keyword">namespace </span>hdstl{
-<a name="l00123"></a>00123 <span class="keyword">namespace </span>concepts{
-<a name="l00124"></a>00124
-<a name="l00125"></a>00125 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
-<a name="l00126"></a>00126 <span class="keyword">struct </span>BackwardHDSConcept {
+<a name="l00120"></a>00120 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_BACKWARDHDSCONCEPT_HPP</span>
+<a name="l00121"></a>00121 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_BACKWARDHDSCONCEPT_HPP 1</span>
+<a name="l00122"></a>00122 <span class="preprocessor"></span>
+<a name="l00123"></a>00123 <span class="keyword">namespace </span>hdstl{
+<a name="l00124"></a>00124 <span class="keyword">namespace </span>concepts{
+<a name="l00125"></a>00125
+<a name="l00138"></a>00138 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
+<a name="l00139"></a>00139 <span class="keyword">struct </span>BackwardHDSConcept {
+<a name="l00140"></a>00140
 <a name="l00143"></a>00143 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::halfedge_descriptor halfedge_descriptor;
 <a name="l00144"></a>00144 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::traversal_category traversal_category;
 <a name="l00145"></a>00145 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::backward_category backward_category;
 <a name="l00146"></a>00146
-<a name="l00148"></a>00148
-<a name="l00149"></a>00149
 <a name="l00150"></a>00150 <span class="keywordtype">void</span> constraints() {
 <a name="l00151"></a>00151 <span class="keyword">using namespace </span>boost;
 <a name="l00152"></a>00152
@@ -41,8 +41,6 @@
 <a name="l00162"></a>00162 const_constraints(hds);
 <a name="l00163"></a>00163 }
 <a name="l00164"></a>00164
-<a name="l00166"></a>00166
-<a name="l00167"></a>00167
 <a name="l00168"></a>00168 <span class="keywordtype">void</span> const_constraints(HDS <span class="keyword">const</span>&amp; hds){
 <a name="l00169"></a>00169 h = prev_in_facet(hds,h);
 <a name="l00170"></a>00170 h = prev_at_source(hds,h);
@@ -50,18 +48,17 @@
 <a name="l00172"></a>00172 }
 <a name="l00173"></a>00173
 <a name="l00174"></a>00174 <span class="keyword">private</span>:
-<a name="l00176"></a>00176
-<a name="l00177"></a>00177
 <a name="l00178"></a>00178 BackwardHDS hds; <span class="comment">// a halfedge data structure object</span>
 <a name="l00179"></a>00179 halfedge_descriptor h; <span class="comment">// a halfedge descriptor</span>
 <a name="l00180"></a>00180 halfedge_descriptor g; <span class="comment">// another halfedge descriptor</span>
-<a name="l00181"></a>00181 };
-<a name="l00182"></a>00182
-<a name="l00183"></a>00183 } <span class="comment">// close namespace concepts</span>
-<a name="l00184"></a>00184 } <span class="comment">// close namespace hdstl</span>
-<a name="l00185"></a>00185
-<a name="l00186"></a>00186 <span class="preprocessor">#endif</span>
-</pre></div><hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<a name="l00182"></a>00182 <span class="comment"></span> };
+<a name="l00183"></a>00183
+<a name="l00184"></a>00184 } <span class="comment">// close namespace concepts</span>
+<a name="l00185"></a>00185 } <span class="comment">// close namespace hdstl</span>
+<a name="l00186"></a>00186
+<a name="l00187"></a>00187 <span class="preprocessor">#endif</span>
+<a name="l00188"></a>00188 <span class="preprocessor"></span>
+</pre></div><hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backward__hds__concept_8hpp.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,6 +8,7 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
@@ -23,7 +24,7 @@
 <p>
 This file provides a single class template that, when used with the following concept-checking utilities: <div class="fragment"><pre class="fragment"> boost::function_requires&lt;BackwardHDSConcept&lt;HDS&gt; &gt;();
 </pre></div> inside a function body, or <div class="fragment"><pre class="fragment"> BOOST_CLASS_REQUIRE(HDS, boost::hdstl, BackwardHDSConcept);
-</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="backwardhds.html">Backward HDS concept</a>. <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="backwardhds.html">Backward HDS concept</a>. <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backwardhds.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backwardhds.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/backwardhds.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,6 +8,7 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li>Files</li>
     <li>Related Pages</li>
   </ul></div>
@@ -74,7 +75,7 @@
      halfedge_descriptor h;
      halfedge_descriptor g;
   };
-</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/files.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/files.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/files.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,15 +8,31 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>HDSTL File List</h1>Here is a list of all files with brief descriptions:<table>
   <tr><td class="indexkey"><a class="el" href="backward__hds__concept_8hpp.html">backward_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>BackwardHDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="bidirectional__hds__concept_8hpp.html">bidirectional_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>BidirectionalHDS</code> concept definition, and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="facet__hds__concept_8hpp.html">facet_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>FacetHDS</code> concept definition, and concept checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="facet__list__hds__concept_8hpp.html">facet_list_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>FacetListHDS</code> concept definition, and concept checking class </td></tr>
   <tr><td class="indexkey"><a class="el" href="forward__hds__concept_8hpp.html">forward_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>ForwardHDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="forward__hds__concept__archetype_8hpp.html">forward_hds_concept_archetype.hpp</a> [code]</td><td class="indexvalue">Provide a <code>ForwardHDS</code> concept archetype </td></tr>
+ <tr><td class="indexkey"><a class="el" href="halfedge__list__hds__concept_8hpp.html">halfedge_list_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>HalfedgeListHDS</code> concept definition, and concept checking class </td></tr>
   <tr><td class="indexkey"><a class="el" href="hds__concept_8hpp.html">hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>HDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="hds__concept__archetype_8hpp.html">hds_concept_archetype.hpp</a> [code]</td><td class="indexvalue">Provide a <code>HDSConcept</code> archetype </td></tr>
+ <tr><td class="indexkey"><a class="el" href="hds__concepts_8hpp.html">hds_concepts.hpp</a> [code]</td><td class="indexvalue">Provides concept checking classes for HDS-related concepts </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__backward__hds__concept_8hpp.html">mutable_backward_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableBackwardHDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__bidirectional__hds__concept_8hpp.html">mutable_bidirectional_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableBidirectionalHDS</code> concept definition, and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__facet__hds__concept_8hpp.html">mutable_facet_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableFacetHDS</code> concept definition, and concept checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__forward__hds__concept_8hpp.html">mutable_forward_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableForwardHDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__hds__concept_8hpp.html">mutable_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableHDS</code> concept definition and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="mutable__vertex__hds__concept_8hpp.html">mutable_vertex_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>MutableVertexHDS</code> concept definition, and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="vertex__hds__concept_8hpp.html">vertex_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>VertexHDS</code> concept definition, and concept-checking class </td></tr>
+ <tr><td class="indexkey"><a class="el" href="vertex__list__hds__concept_8hpp.html">vertex_list_hds_concept.hpp</a> [code]</td><td class="indexvalue">Provide <code>VertexListHDS</code> concept definition, and concept checking class </td></tr>
 </table>
-<hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp-source.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp-source.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp-source.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,24 +8,24 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>forward_hds_concept.hpp</h1>Go to the documentation of this file.<div class="fragment"><pre class="fragment"><a name="l00001"></a>00001
-<a name="l00119"></a>00119 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_FORWARDHDSCONCEPT_HPP</span>
-<a name="l00120"></a>00120 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_FORWARDHDSCONCEPT_HPP 1</span>
-<a name="l00121"></a>00121 <span class="preprocessor"></span>
-<a name="l00122"></a>00122 <span class="keyword">namespace </span>hdstl{
-<a name="l00123"></a>00123 <span class="keyword">namespace </span>concepts{
-<a name="l00124"></a>00124
-<a name="l00125"></a>00125 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
-<a name="l00126"></a>00126 <span class="keyword">struct </span>ForwardHDSConcept {
+<a name="l00120"></a>00120 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_FORWARDHDSCONCEPT_HPP</span>
+<a name="l00121"></a>00121 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_FORWARDHDSCONCEPT_HPP 1</span>
+<a name="l00122"></a>00122 <span class="preprocessor"></span>
+<a name="l00123"></a>00123 <span class="keyword">namespace </span>hdstl{
+<a name="l00124"></a>00124 <span class="keyword">namespace </span>concepts{
+<a name="l00125"></a>00125
+<a name="l00138"></a>00138 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
+<a name="l00139"></a>00139 <span class="keyword">struct </span>ForwardHDSConcept {
+<a name="l00140"></a>00140
 <a name="l00143"></a>00143 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::halfedge_descriptor halfedge_descriptor;
 <a name="l00144"></a>00144 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::traversal_category traversal_category;
 <a name="l00145"></a>00145 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::forward_category forward_category;
 <a name="l00146"></a>00146
-<a name="l00148"></a>00148
-<a name="l00149"></a>00149
 <a name="l00150"></a>00150 <span class="keywordtype">void</span> constraints() {
 <a name="l00151"></a>00151 <span class="keyword">using namespace </span>boost;
 <a name="l00152"></a>00152
@@ -41,8 +41,6 @@
 <a name="l00162"></a>00162 const_constraints(hds);
 <a name="l00163"></a>00163 }
 <a name="l00164"></a>00164
-<a name="l00166"></a>00166
-<a name="l00167"></a>00167
 <a name="l00168"></a>00168 <span class="keywordtype">void</span> const_constraints(HDS <span class="keyword">const</span>&amp; hds){
 <a name="l00169"></a>00169 h = next_in_facet(hds,h);
 <a name="l00170"></a>00170 h = next_at_source(hds,h);
@@ -50,18 +48,17 @@
 <a name="l00172"></a>00172 }
 <a name="l00173"></a>00173
 <a name="l00174"></a>00174 <span class="keyword">private</span>:
-<a name="l00176"></a>00176
-<a name="l00177"></a>00177
 <a name="l00178"></a>00178 ForwardHDS hds; <span class="comment">// a halfedge data structure object</span>
 <a name="l00179"></a>00179 halfedge_descriptor h; <span class="comment">// a halfedge descriptor</span>
 <a name="l00180"></a>00180 halfedge_descriptor g; <span class="comment">// another halfedge descriptor</span>
-<a name="l00181"></a>00181 };
-<a name="l00182"></a>00182
-<a name="l00183"></a>00183 } <span class="comment">// close namespace concepts</span>
-<a name="l00184"></a>00184 } <span class="comment">// close namespace hdstl</span>
-<a name="l00185"></a>00185
-<a name="l00186"></a>00186 <span class="preprocessor">#endif</span>
-</pre></div><hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<a name="l00182"></a>00182 <span class="comment"></span> };
+<a name="l00183"></a>00183
+<a name="l00184"></a>00184 } <span class="comment">// close namespace concepts</span>
+<a name="l00185"></a>00185 } <span class="comment">// close namespace hdstl</span>
+<a name="l00186"></a>00186
+<a name="l00187"></a>00187 <span class="preprocessor">#endif</span>
+<a name="l00188"></a>00188 <span class="preprocessor"></span>
+</pre></div><hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forward__hds__concept_8hpp.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,6 +8,7 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
@@ -23,7 +24,7 @@
 <p>
 This file provides a single class template that, when used with the following concept-checking utilities: <div class="fragment"><pre class="fragment"> boost::function_requires&lt;ForwardHDSConcept&lt;HDS&gt; &gt;();
 </pre></div> inside a function body, or <div class="fragment"><pre class="fragment"> BOOST_CLASS_REQUIRE(HDS, boost::hdstl, ForwardHDSConcept);
-</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="forwardhds.html">Forward HDS concept</a>. <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="forwardhds.html">Forward HDS concept</a>. <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forwardhds.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forwardhds.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/forwardhds.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,6 +8,7 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li>Files</li>
     <li>Related Pages</li>
   </ul></div>
@@ -36,7 +37,7 @@
 <h2><a class="anchor" name="refforwardhds7">
 Expression Semantics</a></h2>
 In addition to the expression semantics of the <code>HDS</code> concept:<ul>
-<li><code>next_in_facet(hds,h)</code> returns a halfedge descriptor to the halfedge preceding <code>h</code> in the adjacent facet cycle, when facet cycles are oriented in counter-clockwise order.</li><li><code>next_at_source(hds,h)</code> returns a halfedge descriptor to the halfedge preceding <code>h</code> around the source vertex of <code>h</code>, when halfedges are ordered around a given vertex in clockwise order.</li><li><code>next_at_target(hds,h)</code> returns a halfedge descriptor to the halfedge preceding <code>h</code> around the target vertex of <code>h</code>, when halfedges are ordered around a given vertex in clockwise order.</li></ul>
+<li><code>next_in_facet(hds,h)</code> returns a halfedge descriptor to the halfedge succeeding <code>h</code> in the adjacent facet cycle, when facet cycles are oriented in counter-clockwise order.</li><li><code>next_at_source(hds,h)</code> returns a halfedge descriptor to the halfedge succeeding <code>h</code> around the source vertex of <code>h</code>, when halfedges are ordered around a given vertex in clockwise order.</li><li><code>next_at_target(hds,h)</code> returns a halfedge descriptor to the halfedge succeeding <code>h</code> around the target vertex of <code>h</code>, when halfedges are ordered around a given vertex in clockwise order.</li></ul>
 <h2><a class="anchor" name="refforwardhds8">
 Complexity guarantees</a></h2>
 <ul>
@@ -74,7 +75,7 @@
      halfedge_descriptor h;
      halfedge_descriptor g;
   };
-</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp-source.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp-source.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp-source.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,23 +8,23 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>hds_concept.hpp</h1>Go to the documentation of this file.<div class="fragment"><pre class="fragment"><a name="l00001"></a>00001
-<a name="l00086"></a>00086 <span class="preprocessor">#include &lt;boost/concepts.h&gt;</span>
-<a name="l00087"></a>00087
-<a name="l00088"></a>00088 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_HDSCONCEPT_HPP</span>
-<a name="l00089"></a>00089 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_HDSCONCEPT_HPP 1</span>
-<a name="l00090"></a>00090 <span class="preprocessor"></span>
-<a name="l00091"></a>00091 <span class="keyword">namespace </span>hdstl{
-<a name="l00092"></a>00092 <span class="keyword">namespace </span>concepts {
-<a name="l00093"></a>00093
-<a name="l00094"></a>00094 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
-<a name="l00095"></a>00095 <span class="keyword">struct </span>HDSConcept {
+<a name="l00087"></a>00087 <span class="preprocessor">#ifdef BOOST_HDSTL_CONCEPTS_HDSCONCEPT_HPP</span>
+<a name="l00088"></a>00088 <span class="preprocessor"></span><span class="preprocessor">#define BOOST_HDSTL_CONCEPTS_HDSCONCEPT_HPP 1</span>
+<a name="l00089"></a>00089 <span class="preprocessor"></span>
+<a name="l00090"></a>00090 <span class="preprocessor">#include &lt;boost/concepts.h&gt;</span>
+<a name="l00091"></a>00091
+<a name="l00092"></a>00092 <span class="keyword">namespace </span>hdstl {
+<a name="l00093"></a>00093 <span class="keyword">namespace </span>concepts {
+<a name="l00094"></a>00094
+<a name="l00107"></a>00107 <span class="keyword">template</span> &lt;<span class="keyword">class</span> HDS&gt;
+<a name="l00108"></a>00108 <span class="keyword">struct </span>HDSConcept {
+<a name="l00109"></a>00109
 <a name="l00112"></a>00112 <span class="keyword">typedef</span> <span class="keyword">typename</span> hds_traits&lt;HDS&gt;::halfedge_descriptor halfedge_descriptor;
-<a name="l00119"></a>00119
-<a name="l00120"></a>00120
 <a name="l00121"></a>00121 <span class="keywordtype">void</span> constraints()
 <a name="l00125"></a>00125 {
 <a name="l00126"></a>00126 <span class="keyword">using namespace </span>boost;
@@ -36,24 +36,23 @@
 <a name="l00132"></a>00132 const_constraints(hds);
 <a name="l00133"></a>00133 }
 <a name="l00134"></a>00134
-<a name="l00136"></a>00136
-<a name="l00137"></a>00137
 <a name="l00138"></a>00138 <span class="keywordtype">void</span> const_constraints(HDS <span class="keyword">const</span>&amp; hds)
 <a name="l00142"></a>00142 {
 <a name="l00143"></a>00143 h = opposite(hds,h);
 <a name="l00144"></a>00144 }
 <a name="l00145"></a>00145
-<a name="l00146"></a>00146 <span class="keyword">private</span>:
-<a name="l00147"></a>00147 <span class="comment">// DATA</span>
-<a name="l00148"></a>00148 HDS hds; <span class="comment">// a halfedge data structure object</span>
-<a name="l00149"></a>00149 halfedge_descriptor h; <span class="comment">// a halfedge descriptor</span>
-<a name="l00150"></a>00150 };
-<a name="l00151"></a>00151
-<a name="l00152"></a>00152 } <span class="comment">// close namespace concepts</span>
-<a name="l00153"></a>00153 } <span class="comment">// close namespace hdstl</span>
-<a name="l00154"></a>00154
-<a name="l00155"></a>00155 <span class="preprocessor">#endif</span>
-</pre></div><hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<a name="l00146"></a>00146 <span class="keyword">private</span>:
+<a name="l00147"></a>00147 <span class="comment">// DATA</span>
+<a name="l00148"></a>00148 HDS hds; <span class="comment">// a halfedge data structure object</span>
+<a name="l00149"></a>00149 halfedge_descriptor h; <span class="comment">// a halfedge descriptor</span>
+<a name="l00151"></a>00151 <span class="comment"></span> };
+<a name="l00152"></a>00152
+<a name="l00153"></a>00153 } <span class="comment">// close namespace concepts</span>
+<a name="l00154"></a>00154 } <span class="comment">// close namespace hdstl</span>
+<a name="l00155"></a>00155
+<a name="l00156"></a>00156 <span class="preprocessor">#endif</span>
+<a name="l00157"></a>00157 <span class="preprocessor"></span>
+</pre></div><hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hds__concept_8hpp.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,12 +8,12 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li id="current">Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>hds_concept.hpp File Reference</h1>Provide <code>HDS</code> concept definition and concept-checking class. More...
 <p>
-<code>#include &lt;boost/concepts.h&gt;</code><br>
 
 <p>
 <a href="hds__concept_8hpp-source.html">Go to the source code of this file.</a><table border="0" cellpadding="0" cellspacing="0">
@@ -24,7 +24,7 @@
 <p>
 This file provides a single class template that, when used with the following concept-checking utilities: <div class="fragment"><pre class="fragment"> boost::function_requires&lt;HDSConcept&lt;HDS&gt; &gt;();
 </pre></div> inside a function body, or <div class="fragment"><pre class="fragment"> BOOST_CLASS_REQUIRE(HDS, boost::hdstl, HDSConcept);
-</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="hdsconcept.html">HDS concept definition</a>. <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> inside a class body, checks whether the type given as template argument is a model of the HDS concept described on the page <a class="el" href="hdsconcept.html">HDS concept definition</a>. <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hdsconcept.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hdsconcept.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/hdsconcept.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,6 +8,7 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li>Files</li>
     <li>Related Pages</li>
   </ul></div>
@@ -56,7 +57,7 @@
     <span class="keywordtype">void</span> const_constraints(HDS <span class="keyword">const</span>&amp; hds) {
       h = opposite(hds,h);
     }
-</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+</pre></div> <hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/index.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/index.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/index.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,12 +8,13 @@
 <div class="tabs">
   <ul>
     <li id="current">Main Page</li>
+ <li>Classes</li>
     <li>Files</li>
     <li>Related Pages</li>
   </ul></div>
 <h1>HDSTL Documentation</h1>
 <p>
-<hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/html/pages.html
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/html/pages.html (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/html/pages.html 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -8,18 +8,43 @@
 <div class="tabs">
   <ul>
     <li>Main Page</li>
+ <li>Classes</li>
     <li>Files</li>
     <li id="current">Related Pages</li>
   </ul></div>
 <h1>HDSTL Related Pages</h1>Here is a list of all related documentation pages:<ul>
 <li><a class="el" href="backwardhds.html">Backward HDS concept</a>
 
+<li><a class="el" href="bidirectionalhds.html">Bidirectional HDS concept</a>
+
+<li><a class="el" href="facethds.html">Facet HDS concept</a>
+
+<li><a class="el" href="facetlisthds.html">Facet List HDS concept</a>
+
 <li><a class="el" href="forwardhds.html">Forward HDS concept</a>
 
+<li><a class="el" href="halfedgelisthds.html">Halfedge List HDS concept</a>
+
 <li><a class="el" href="hdsconcept.html">HDS concept definition</a>
 
+<li><a class="el" href="mutablebackwardhds.html">Mutable Backward HDS concept</a>
+
+<li><a class="el" href="mutablebidirectionalhds.html">Mutable Bidirectional HDS concept</a>
+
+<li><a class="el" href="mutablefacethds.html">Mutable Facet HDS concept</a>
+
+<li><a class="el" href="mutableforwardhds.html">Mutable Forward HDS concept</a>
+
+<li><a class="el" href="mutablehdsconcept.html">Mutable HDS concept definition</a>
+
+<li><a class="el" href="mutablevertexhds.html">Mutable Vertex HDS concept</a>
+
+<li><a class="el" href="vertexhds.html">Vertex HDS concept</a>
+
+<li><a class="el" href="vertexlisthds.html">Vertex List HDS concept</a>
+
 </ul>
-<hr size="1"><address style="align: right;"><small>Generated on Tue Jun 12 02:11:13 2007 for HDSTL by&nbsp;
+<hr size="1"><address style="align: right;"><small>Generated on Thu Jun 14 00:29:34 2007 for HDSTL by&nbsp;
 <a href="http://www.doxygen.org/index.html">
 <img src="doxygen.png" alt="doxygen" align="middle" border="0"></a> 1.4.7 </small></address>
 </body>

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/doxygen.sty
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/doxygen.sty (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/doxygen.sty 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -10,8 +10,8 @@
         {\fancyplain{}{\bfseries\rightmark}}
 \rhead[\fancyplain{}{\bfseries\leftmark}]
         {\fancyplain{}{\bfseries\thepage}}
-\rfoot[\fancyplain{}{\bfseries\scriptsize Generated on Tue Jun 12 02:11:13 2007 for HDSTL by Doxygen }]{}
-\lfoot[]{\fancyplain{}{\bfseries\scriptsize Generated on Tue Jun 12 02:11:13 2007 for HDSTL by Doxygen }}
+\rfoot[\fancyplain{}{\bfseries\scriptsize Generated on Thu Jun 14 00:29:34 2007 for HDSTL by Doxygen }]{}
+\lfoot[]{\fancyplain{}{\bfseries\scriptsize Generated on Thu Jun 14 00:29:34 2007 for HDSTL by Doxygen }}
 \cfoot{}
 \newenvironment{Code}
 {\footnotesize}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/files.tex
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/files.tex (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/files.tex 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -1,6 +1,21 @@
 \section{HDSTL File List}
 Here is a list of all files with brief descriptions:\begin{CompactList}
 \item\contentsline{section}{\bf{backward\_\-hds\_\-concept.hpp} (Provide {\tt Backward\-HDS} concept definition and concept-checking class )}{\pageref{backward__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{bidirectional\_\-hds\_\-concept.hpp} (Provide {\tt Bidirectional\-HDS} concept definition, and concept-checking class )}{\pageref{bidirectional__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{facet\_\-hds\_\-concept.hpp} (Provide {\tt Facet\-HDS} concept definition, and concept checking class )}{\pageref{facet__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{facet\_\-list\_\-hds\_\-concept.hpp} (Provide {\tt Facet\-List\-HDS} concept definition, and concept checking class )}{\pageref{facet__list__hds__concept_8hpp}}{}
 \item\contentsline{section}{\bf{forward\_\-hds\_\-concept.hpp} (Provide {\tt Forward\-HDS} concept definition and concept-checking class )}{\pageref{forward__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{forward\_\-hds\_\-concept\_\-archetype.hpp} (Provide a {\tt Forward\-HDS} concept archetype )}{\pageref{forward__hds__concept__archetype_8hpp}}{}
+\item\contentsline{section}{\bf{halfedge\_\-list\_\-hds\_\-concept.hpp} (Provide {\tt Halfedge\-List\-HDS} concept definition, and concept checking class )}{\pageref{halfedge__list__hds__concept_8hpp}}{}
 \item\contentsline{section}{\bf{hds\_\-concept.hpp} (Provide {\tt HDS} concept definition and concept-checking class )}{\pageref{hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{hds\_\-concept\_\-archetype.hpp} (Provide a {\tt HDSConcept} archetype )}{\pageref{hds__concept__archetype_8hpp}}{}
+\item\contentsline{section}{\bf{hds\_\-concepts.hpp} (Provides concept checking classes for HDS-related concepts )}{\pageref{hds__concepts_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-backward\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-Backward\-HDS} concept definition and concept-checking class )}{\pageref{mutable__backward__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-bidirectional\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-Bidirectional\-HDS} concept definition, and concept-checking class )}{\pageref{mutable__bidirectional__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-facet\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-Facet\-HDS} concept definition, and concept checking class )}{\pageref{mutable__facet__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-forward\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-Forward\-HDS} concept definition and concept-checking class )}{\pageref{mutable__forward__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-HDS} concept definition and concept-checking class )}{\pageref{mutable__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{mutable\_\-vertex\_\-hds\_\-concept.hpp} (Provide {\tt Mutable\-Vertex\-HDS} concept definition, and concept-checking class )}{\pageref{mutable__vertex__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{vertex\_\-hds\_\-concept.hpp} (Provide {\tt Vertex\-HDS} concept definition, and concept-checking class )}{\pageref{vertex__hds__concept_8hpp}}{}
+\item\contentsline{section}{\bf{vertex\_\-list\_\-hds\_\-concept.hpp} (Provide {\tt Vertex\-List\-HDS} concept definition, and concept checking class )}{\pageref{vertex__list__hds__concept_8hpp}}{}
 \end{CompactList}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/forwardhds.tex
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/forwardhds.tex (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/forwardhds.tex 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -17,7 +17,7 @@
 \item {\tt next\_\-in\_\-facet(hds,h)} must return a value assignable to h.\item {\tt next\_\-at\_\-source(hds,h)} must return a value assignable to h.\item {\tt next\_\-at\_\-target(hds,h)} must return a value assignable to h.\end{itemize}
 \subsection{Expression Semantics}\label{forwardhds_refforwardhds7}
 In addition to the expression semantics of the {\tt HDS} concept:\begin{itemize}
-\item {\tt next\_\-in\_\-facet(hds,h)} returns a halfedge descriptor to the halfedge preceding {\tt h} in the adjacent facet cycle, when facet cycles are oriented in counter-clockwise order.\item {\tt next\_\-at\_\-source(hds,h)} returns a halfedge descriptor to the halfedge preceding {\tt h} around the source vertex of {\tt h}, when halfedges are ordered around a given vertex in clockwise order.\item {\tt next\_\-at\_\-target(hds,h)} returns a halfedge descriptor to the halfedge preceding {\tt h} around the target vertex of {\tt h}, when halfedges are ordered around a given vertex in clockwise order.\end{itemize}
+\item {\tt next\_\-in\_\-facet(hds,h)} returns a halfedge descriptor to the halfedge succeeding {\tt h} in the adjacent facet cycle, when facet cycles are oriented in counter-clockwise order.\item {\tt next\_\-at\_\-source(hds,h)} returns a halfedge descriptor to the halfedge succeeding {\tt h} around the source vertex of {\tt h}, when halfedges are ordered around a given vertex in clockwise order.\item {\tt next\_\-at\_\-target(hds,h)} returns a halfedge descriptor to the halfedge succeeding {\tt h} around the target vertex of {\tt h}, when halfedges are ordered around a given vertex in clockwise order.\end{itemize}
 \subsection{Complexity guarantees}\label{forwardhds_refforwardhds8}
 \begin{itemize}
 \item {\tt next\_\-in\_\-facet(hds,h)}: amortized constant time.\item {\tt next\_\-at\_\-source(hds,h)}: amortized constant time.\item {\tt next\_\-at\_\-target(hds,h)}: amortized constant time.\end{itemize}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/hds__concept_8hpp.tex
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/hds__concept_8hpp.tex (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/hds__concept_8hpp.tex 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -2,7 +2,6 @@
 \label{hds__concept_8hpp}\index{hds_concept.hpp@{hds\_\-concept.hpp}}
 Provide {\tt HDS} concept definition and concept-checking class.
 
-{\tt \#include $<$boost/concepts.h$>$}\par
 
 
 \subsection{Detailed Description}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/pages.tex
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/pages.tex (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/pages.tex 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -2,8 +2,32 @@
 Here is a list of all related documentation pages:\begin{CompactList}
 \item \contentsline{section}{Backward HDS concept}{\pageref{backwardhds}}{}
 
+\item \contentsline{section}{Bidirectional HDS concept}{\pageref{bidirectionalhds}}{}
+
+\item \contentsline{section}{Facet HDS concept}{\pageref{facethds}}{}
+
+\item \contentsline{section}{Facet List HDS concept}{\pageref{facetlisthds}}{}
+
 \item \contentsline{section}{Forward HDS concept}{\pageref{forwardhds}}{}
 
+\item \contentsline{section}{Halfedge List HDS concept}{\pageref{halfedgelisthds}}{}
+
 \item \contentsline{section}{HDS concept definition}{\pageref{hdsconcept}}{}
 
+\item \contentsline{section}{Mutable Backward HDS concept}{\pageref{mutablebackwardhds}}{}
+
+\item \contentsline{section}{Mutable Bidirectional HDS concept}{\pageref{mutablebidirectionalhds}}{}
+
+\item \contentsline{section}{Mutable Facet HDS concept}{\pageref{mutablefacethds}}{}
+
+\item \contentsline{section}{Mutable Forward HDS concept}{\pageref{mutableforwardhds}}{}
+
+\item \contentsline{section}{Mutable HDS concept definition}{\pageref{mutablehdsconcept}}{}
+
+\item \contentsline{section}{Mutable Vertex HDS concept}{\pageref{mutablevertexhds}}{}
+
+\item \contentsline{section}{Vertex HDS concept}{\pageref{vertexhds}}{}
+
+\item \contentsline{section}{Vertex List HDS concept}{\pageref{vertexlisthds}}{}
+
 \end{CompactList}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/refman.tex
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/refman.tex (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/doc/latex/refman.tex 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -19,7 +19,7 @@
 \vspace*{1cm}
 {\large Generated by Doxygen 1.4.7}\\
 \vspace*{0.5cm}
-{\small Tue Jun 12 02:11:13 2007}\\
+{\small Thu Jun 14 00:29:34 2007}\\
 \end{center}
 \end{titlepage}
 \clearemptydoublepage
@@ -27,17 +27,49 @@
 \tableofcontents
 \clearemptydoublepage
 \pagenumbering{arabic}
+\chapter{HDSTL Class Index}
+\input{annotated}
 \chapter{HDSTL File Index}
 \input{files}
 \chapter{HDSTL Page Index}
 \input{pages}
+\chapter{HDSTL Class Documentation}
+\input{structhds__traits_3_01HDSConcept__archetype_01_4}
+\include{classHDSConcept__archetype}
 \chapter{HDSTL File Documentation}
 \input{backward__hds__concept_8hpp}
+\include{bidirectional__hds__concept_8hpp}
+\include{facet__hds__concept_8hpp}
+\include{facet__list__hds__concept_8hpp}
 \include{forward__hds__concept_8hpp}
+\include{forward__hds__concept__archetype_8hpp}
+\include{halfedge__list__hds__concept_8hpp}
 \include{hds__concept_8hpp}
+\include{hds__concept__archetype_8hpp}
+\include{hds__concepts_8hpp}
+\include{mutable__backward__hds__concept_8hpp}
+\include{mutable__bidirectional__hds__concept_8hpp}
+\include{mutable__facet__hds__concept_8hpp}
+\include{mutable__forward__hds__concept_8hpp}
+\include{mutable__hds__concept_8hpp}
+\include{mutable__vertex__hds__concept_8hpp}
+\include{vertex__hds__concept_8hpp}
+\include{vertex__list__hds__concept_8hpp}
 \chapter{HDSTL Page Documentation}
 \input{backwardhds}
+\include{bidirectionalhds}
+\include{facethds}
+\include{facetlisthds}
 \include{forwardhds}
+\include{halfedgelisthds}
 \include{hdsconcept}
+\include{mutablebackwardhds}
+\include{mutablebidirectionalhds}
+\include{mutablefacethds}
+\include{mutableforwardhds}
+\include{mutablehdsconcept}
+\include{mutablevertexhds}
+\include{vertexhds}
+\include{vertexlisthds}
 \printindex
 \end{document}

Modified: sandbox/SOC/2007/geometry/libs/hdstl/tools/doc.pl
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/tools/doc.pl (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/tools/doc.pl 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -109,6 +109,7 @@
 my $conceptRef = 0; # numbers the section references
 my $classOpen = 0; # serves to know if we're within a class body
 my $className = ""; # and if so, the class name
+my $templateName = ""; # and any template parameters (one line before the class def)
 my $groupOpen = 0; # serves to close a named group before opening another
 
 sub process_toplevel_comment_line {
@@ -242,23 +243,23 @@
             print $content;
         } elsif ($content =~ m/(NOT IMPL|TYPE|DATA|CREATOR|MANIP|ACCESS)/) {
             if ($groupOpen) {
- print $prefix."//\@\}\n";
+ print $prefix."/** \@\} */\n";
             }
             $groupOpen = 1;
             if ($content =~ m/TYPE/) {
- print $prefix."//\@\{\n";
+ print $prefix."/** \@\{ */\n";
                 print $prefix.'/** @name Member types'." */\n";
             } elsif ($content =~ m/DATA/) {
- print $prefix."//\@\{\n";
+ print $prefix."/** \@\{ */\n";
                 print $prefix.'/** @name Data members'." */\n";
             } elsif ($content =~ m/CREATOR/) {
- print $prefix."//\@\{\n";
+ print $prefix."/** \@\{ */\n";
                 print $prefix.'/** @name Constructors, destructor'." */\n";
             } elsif ($content =~ m/MANIP/) {
- print $prefix."//\@\{\n";
+ print $prefix."/** \@\{ */\n";
                 print $prefix.'/** @name Manipulators'." */\n";
             } elsif ($content =~ m/ACCESS/) {
- print $prefix."//\@\{\n";
+ print $prefix."/** \@\{ */\n";
                 print $prefix.'/** @name Accessors'." */\n";
             } elsif ($content =~ m/NOT IMPL/) {
                 print $prefix."/* Not implemented */\n";
@@ -272,9 +273,7 @@
             if ($className eq "") {
                 print $1."/**< ".process_font($2)."\n";
             } else {
- print $1."/** \\class ".$className."\n".
- $1." * ".process_font($2)."\n";
- $className = "";
+ print $1."/** ".process_font($2)."\n";
             }
             my $comment = <>;
             while ($comment =~ m/^( *)\/\/(.*)$/) {
@@ -282,11 +281,17 @@
                 $comment = <>;
             }
             print $1." **/\n";
+ if (!($className eq "")) {
+ print $templateName;
+ print $className;
+ $className = "";
+ $templateName = "";
+ }
             if ($comment !~ m/^( *)\};/) {
                 process_class_line($comment);
             } else {
                 if ($groupOpen == 1) {
- print " //\@\}\n";
+ print " /** \@\} */\n";
                     $groupOpen = 0;
                 }
                 $classOpen = 0;
@@ -298,6 +303,30 @@
     }
 }
 
+sub parse_class_code {
+ $classOpen = 1;
+ $groupOpen = 0;
+ my $classLine = <>;
+ while ($classLine !~ m/^( *)\};/) {
+ process_class_line($classLine);
+ # The following is a dirty hack - we read the end of line already
+ # and now we still must exit the loop...
+ if (0 == $classOpen) {
+ $classLine = "};\n";
+ } else {
+ $classLine = <>;
+ }
+ }
+ if ($groupOpen == 1) {
+ print " /** \@\} */\n";
+ $groupOpen = 0;
+ }
+ print $classLine;
+ $classOpen = 0;
+ $className = "";
+ $templateName = "";
+}
+
 # MAIN LOOP
 
 while(<>) {
@@ -322,30 +351,12 @@
             print $_;
         }
     }
+ elsif ($_ =~ m/^( *)template *(<.*>)/) {
+ $templateName = $_;
+ }
     elsif ($_ =~ m/^( *)(class|struct|union) +([a-zA-Z][a-zA-Z_]*)[^{]*\{/) {
- $classOpen = 1;
- $groupOpen = 0;
- $className = $3;
- print $_;
-
- my $classLine = <>;
- while ($classLine !~ m/^( *)\};/) {
- process_class_line($classLine);
- # The following is a dirty hack - we read the end of line already
- # and now we still must exit the loop...
- if (0 == $classOpen) {
- $classLine = "};\n";
- } else {
- $classLine = <>;
- }
- }
- if ($groupOpen == 1) {
- print " //\@\}\n";
- $groupOpen = 0;
- }
- print $classLine;
- $classOpen = 0;
- $className = "";
+ $className = $_;
+ parse_class_code;
     }
     else {
         # C++ code or C-style comments outside class definition scope.

Deleted: sandbox/SOC/2007/geometry/libs/hdstl/tools/make_doc.sh
==============================================================================
--- sandbox/SOC/2007/geometry/libs/hdstl/tools/make_doc.sh 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
+++ (empty file)
@@ -1,8 +0,0 @@
-#!/bin/zsh
-
-# define
-# HDSTL_ROOT= libs/hdstl
-
-foreach file in $*
- $HDSTL_ROOT/tools/doc.pl $file >! $HDSTL_ROOT/dev/doxy/`basename $file`
-end


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/hds_concept_archetype.hpp (original)
+++ sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_archetypes/hds_concept_archetype.hpp 2007-06-14 00:35:43 EDT (Thu, 14 Jun 2007)
@@ -1,40 +1,75 @@
-/**
- * @file hds_concept_archetype.hpp
- *
- * @brief HDS concept archetype
- *
- * @par Definition
- * This file provides an archetype class for compile time testing of the
- * HDSConcept class.
- *
- * @par Archetype class
- * \code
- * class HDSConcept_archetype {
- * public:
- * halfedge_descriptor& opposite(halfedge_descriptor&) const{};
- * };
- * template<>
- * class hds_traits<HDSConcept_archetype> {
- * struct halfedge_descriptor
- * :public boost::default_constructible_archetype,
- * boost::copy_constructible_archetype,
- * boost::equality_comparable_archetype,
- * boost::assignable_archetype {};
- * };
- * \endcode
- */
+// hds_concept_archetype.hpp -*- C++ -*-
+//
+//@PURPOSE: Provide a 'HDSConcept' archetype
+//
+//@DESCRIPTION: This file provides an archetype class for compile-time testing
+// of the 'HDSConcept' class. Namely, this class can be used wherever a
+// template parameter of a class or of a function template is required to be a
+// model of the 'HDS' concept, in order to ensure that no further
+// requirements are placed on the template parameter than are stated in the
+// 'HDS' concept.
+//
+///Archetype class
+///---------------
+//..
+// class HDSConcept_archetype {
+// typedef typename hds_traits<HDSConcept_archetype
+// >::halfedge_descriptor halfedge_descriptor;
+// public:
+// halfedge_descriptor& opposite(halfedge_descriptor&) const;
+// };
+//
+// template<>
+// struct hds_traits<HDSConcept_archetype> {
+// typedef boost::default_constructible_archetype<
+// boost::copy_constructible_archetype<
+// boost::equality_comparable_archetype<
+// boost::assignable_archetype<> > > > halfedge_descriptor;
+// };
+//..
+
+#ifndef BOOST_HDSTL_HDS_CONCEPT_ARCHETYPE_HPP
+#define BOOST_HDSTL_HDS_CONCEPT_ARCHETYPE_HPP
+
 #include <boost/concept_archetype.hpp>
 
-class HDSConcept_archetype {
- public:
- halfedge_descriptor& opposite(halfedge_descriptor&) const{};
-};
+class HDSConcept_archetype; // forward declaration
 
 template<>
-class hds_traits<HDSConcept_archetype> {
- struct halfedge_descriptor
- :public boost::default_constructible_archetype,
- boost::copy_constructible_archetype,
- boost::equality_comparable_archetype,
- boost::assignable_archetype {};
+struct hds_traits<HDSConcept_archetype> {
+ // This template specialization of 'hds_traits' for the
+ // 'HDSConcept_archetype' provides the 'halfedge_descriptor' type.
+
+ // TYPES
+ typedef boost::default_constructible_archetype<
+ boost::copy_constructible_archetype<
+ boost::equality_comparable_archetype<
+ boost::assignable_archetype<> > > > halfedge_descriptor;
+ // Halfedge descriptor type for the 'HDSConcept' archetype.
+};
+
+class HDSConcept_archetype {
+ // This archetype class for the 'HDSConcept' class can be used wherever a
+ // template parameter of a class or of a function template is required to be a
+ // model of the 'HDS' concept, in order to ensure that no further
+ // requirements are placed on the template parameter than are stated in the
+ // 'HDS' concept.
+
+ // PRIVATE TYPES
+ typedef typename hds_traits<HDSConcept_archetype
+ >::halfedge_descriptor halfedge_descriptor;
+
+ public:
+ halfedge_descriptor& opposite(halfedge_descriptor&) const;
+ // Return the halfedge opposite 'h' in 'hds'.
 };
+
+// MANIPULATORS
+typename hds_traits<HDSConcept_archetype>::halfedge_descriptor
+HDSConcept_archetype::opposite(ForwardHDSConcept_archetype const& hds,
+ halfedge_descriptor h)
+{
+ return halfedge_descriptor();
+}
+
+#endif

Modified: sandbox/SOC/2007/geometry/libs/hdstl/dev/hds_concepts/mutable_vertex_hds_concept.hpp
==============================================================================